Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/push-mlperf-inference-results-to-github](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/push-mlperf-inference-results-to-github) for the documentation of this CM script.
